==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-6f.js <==
dispMUA.arDispMUAAllocation["o"] =
{
  "o3sis o2 communication center mail" : [ "o2.png" , "http://www.o2.com/" ] ,
  "outlook connector for mdaemon" : [ "outlook_connector_mdaemon.png" , "http://www.altn.com/Products/CollaborationSolutions/OutlookConnector/" ] ,
  "ocxqmail from flicks software" : [ "flicks_software.png" , "http://www.flicks.com/ocxQmail/" ] ,
  "octeth email manager pro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "openwave webengine" : [ "openwave.png" ] ,
  "otrs mail service" : [ "otrs.png" ] ,
  "opengroupware.org" : [ "opengroupware.png" ] ,
  "office.freenet.de" : [ "freenet.png" , "http://office.freenet.de/" ] ,
  "outlook express" : [ "outlook_express.png" , "http://www.microsoft.com/" ] ,
  "orbiz digitrade" : [ "orbiz.png" , "http://www.orbiz.com/Online-Shop-Software--7d.html" ] ,
  "ostrosoft smtp" : [ "ostrosoft_smtp.png" ] ,
  "o2.pl webmail" : [ "o2_pl.png" , "http://www.o2.pl/" ] ,
  "opensmtp.net" : [ "opensmtp-net.png" , "http://sourceforge.net/projects/opensmtp-net/" ] ,
  "open-xchange" : [ "open_xchange.png" ] ,
  "open webmail" : [ "openwebmail.png" ] ,
  "oikal-web.de" : [ "oikal.png" ] ,
  "openwebmail" : [ "openwebmail.png" ] ,
  "openphpnuke" : [ "openphpnuke.png" ] ,
  "onet.poczta" : [ "onet_poczta.png" ] ,
  "osso email" : [ "osso-email.png" , "https://stage.maemo.org/svn/maemo/projects/email/osso-email/trunk/" ] ,
  "oscommerce" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "osc mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "one mailer" : [ "onemailer_com.png" , "http://www.onemailer.com/" ] ,
  "officetalk" : [ "officetalk.png" ] ,
  "online.ua" : [ "online_ua.png" , "http://www.online.ua/" ] ,
  "omnixmail" : [ "omnixmail.png" ] ,
  "openemm" : [ "openemm.png" , "http://www.openemm.org/" ] ,
  "oracle" : [ "oracle.png" ] ,
  "openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "oempro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "opera" : [ "opera.png" ] ,
  "omail" : [ "omail.png" , "http://omail.omnis.ch/" ] ,
  "ontap" : [ "netapp.png" , "http://www.netapp.com/" ] ,
  "ozum" : [ "ozum.png" ] ,
  "ovh" : [ "ovh.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-6f.js <==
dispMUA.arDispMUAAllocation["o"] =
{
  "o3sis o2 communication center mail" : [ "o2.png" , "http://www.o2.com/" ] ,
  "outlook connector for mdaemon" : [ "outlook_connector_mdaemon.png" , "http://www.altn.com/Products/CollaborationSolutions/OutlookConnector/" ] ,
  "ocxqmail from flicks software" : [ "flicks_software.png" , "http://www.flicks.com/ocxQmail/" ] ,
  "octeth email manager pro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "openwave webengine" : [ "openwave.png" ] ,
  "otrs mail service" : [ "otrs.png" ] ,
  "opengroupware.org" : [ "opengroupware.png" ] ,
  "office.freenet.de" : [ "freenet.png" , "http://office.freenet.de/" ] ,
  "outlook express" : [ "ms_outlook_express.png" , "http://www.microsoft.com/" ] ,
  "orbiz digitrade" : [ "orbiz.png" , "http://www.orbiz.com/Online-Shop-Software--7d.html" ] ,
  "ostrosoft smtp" : [ "ostrosoft_smtp.png" ] ,
  "openoffice.org" : [ "openoffice.png" , "http://www.openoffice.org/" ] ,
  "ogilvy express" : [ "ogilvy-express.png" , "http://www.ogilvy.com/" ] ,
  "o2.pl webmail" : [ "o2_pl.png" , "http://www.o2.pl/" ] ,
  "opensmtp.net" : [ "opensmtp-net.png" , "http://sourceforge.net/projects/opensmtp-net/" ] ,
  "open-xchange" : [ "open_xchange.png" ] ,
  "open webmail" : [ "openwebmail.png" ] ,
  "oikal-web.de" : [ "oikal.png" ] ,
  "openwebmail" : [ "openwebmail.png" ] ,
  "openphpnuke" : [ "openphpnuke.png" ] ,
  "onet.poczta" : [ "onet_poczta.png" ] ,
  "osso email" : [ "osso-email.png" , "https://stage.maemo.org/svn/maemo/projects/email/osso-email/trunk/" ] ,
  "oscommerce" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "osc mailer" : [ "oscommerce.png" , "http://www.oscommerce.org/" ] ,
  "one mailer" : [ "onemailer_com.png" , "http://www.onemailer.com/" ] ,
  "officetalk" : [ "officetalk.png" ] ,
  "online.ua" : [ "online_ua.png" , "http://www.online.ua/" ] ,
  "omnixmail" : [ "omnixmail.png" ] ,
  "openemm" : [ "openemm.png" , "http://www.openemm.org/" ] ,
  "oracle" : [ "oracle.png" ] ,
  "openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "oempro" : [ "oempro.png" , "http://www.octeth.com/" ] ,
  "opera" : [ "opera.png" ] ,
  "omail" : [ "omail.png" , "http://omail.omnis.ch/" ] ,
  "ontap" : [ "netapp.png" , "http://www.netapp.com/" ] ,
  "ozum" : [ "ozum.png" ] ,
  "ovh" : [ "ovh.png" ] ,
}
